# A simple functor object for encapsulating filter functions

### CLASSDEF

setClass("FunctionalTokenFilter",
  representation("TokenFilter", fun="function", negate="logical"))

### GENERICS

setGeneric("isNegated",  function (object) standardGeneric("isNegated"))

setGeneric("func", function (object) standardGeneric("func"))

setGeneric("FunctionalTokenFilter",
  function(fun, negate) standardGeneric("FunctionalTokenFilter"))

### CONSTRUCTOR

setMethod("FunctionalTokenFilter", signature(fun="function",
                                             negate="logical"),
  function (fun, negate)
    new("FunctionalTokenFilter", fun=fun, negate=negate))

setMethod("FunctionalTokenFilter", signature(fun="function",
                                             negate="missing"),
  function (fun, negate) FunctionalTokenFilter(fun, FALSE))

### ACCESSORS

setMethod("func", "FunctionalTokenFilter",
  function (object) object@fun)

setMethod("isNegated", "FunctionalTokenFilter",
  function (object) object@negate)

### MERGE overrriding

setMethod("mergeFilters", signature(f1="FunctionalTokenFilter",
                                    f2="FunctionalTokenFilter"),
  function (f1, f2) {
    fun1 <- func(f1)
    fun2 <- func(f2)

    if (isNegated(f1))
      fn1 <- function (x) ! fun1(x)
    else
      fn1 <- function (x) fun1(x)

    if (isNegated(f2))
      fn2 <- function (x) ! fun2(x)
    else
      fn2 <- function (x) fun2(x)

    fun <- function (x) fn1(x) & fn2(x)

    new("FunctionalTokenFilter", fun=fun, negate=FALSE)
  })

### FILTER overriding

# Filters the given string, or vector of tokens, but always break a
# TextDocument down into its tokens first.
setMethod("filterTokens", signature(object="character", 
                                    filter="FunctionalTokenFilter",
                                    tokenizer="missing", index="missing"), 
  function(object, filter, tokenizer, index)  {
    if (is(object, "TextDocument"))
      object <- tokenize(object)

    fun <- func(filter)

    if (isNegated(filter))
      fn <- function (x) ! fun(x)
    else
      fn <- fun
    object[ fn(object) ]
  })
      
