# A simple wrapper around the stemmer provided by rstem.

### CLASSDEF

setClass("SnowballStemmer",
  representation("Stemmer", language = "character"))

### GENERICS

setGeneric("language", function (object) standardGeneric("language"))

### CONSTRUCTOR

SnowballStemmer <- function (language = "english") {
  if (! (language %in% getStemLanguages()))
    stop(paste(language, "is not a valid Snowball stemmer language."))
  new("SnowballStemmer", language=language)
}

### ACCESSORS

# Get the language of this stemmer
setMethod("language", "SnowballStemmer", function (object) object@language)

### STEM overriding

# Stems the given string, or vector of tokens, but always break a
# TextDocument down into its tokens first.
setMethod("stem", signature(object="character", 
                            stemmer="SnowballStemmer",
                            tokenizer="missing", index="missing"), 
  function(object, stemmer, tokenizer, index) 
    if (is(object, "TextDocument"))
      wordStem(tokenize(object), language(stemmer))
    else
      wordStem(object, language(stemmer)))
