# A view of a CorpusRef that has been tokenized and stemmed in some way.

### CLASS DEF

setClass("StemmedCorpusView",
    representation("TokenizedCorpusView", "StemmedView"))

### VALIDITY

# XXX TODO

### Various functions

### GENERICS

setGeneric("StemmedCorpusView",
  function (corpus, stemmer, tokenizer)
    standardGeneric("StemmedCorpusView"))

### CONSTRUCTION

# Constructs a new StemmeddCorpusView from given corpus and tokenizer.
# This constructor is not intended to be part of the external api and
# users will generate TokenizedCorpusViews with the tokenize method.
# Always use this function to generate SCVs within the library.
setMethod("StemmedCorpusView", "PCorpus",
  function(corpus, stemmer, tokenizer) {
    documentViews <- new("NULLlist")
    tokenFreqTable <- new("NULLtable")
    uniqueTokens <- new("NULLcharacter")
    documentTokenMatrix <- new("NULLTermDocMatrix")

    res<- new("StemmedCorpusView", corpus=corpus, tokenizer=tokenizer,
              documentViews=documentViews,
              tokenFreqTable=tokenFreqTable,
              uniqueTokens = uniqueTokens,
              documentTokenMatrix=documentTokenMatrix,
            stemmer=stemmer)
    registerView(corpus, res)
    res
  }
)

### ACCESSORS / MODIFIERS (lazy loading)

# Returns the documentViews of the underlying documents
setMethod("documentViews", "StemmedCorpusView", 
  function (object) {
    if (is(ref(object, "documentViews"), "NULLlist")) {
      sdvs <- lapply(1:length(corpus(object)),
        function (x) stem(corpus(object), stemmer(object),
                          tokenizer(object), x))
      names(sdvs) <- sapply(corpus(object), ID)
      (ref(object, "documentViews") <- sdvs)
    } else
      ref(object, "documentViews")
  }
)

# UTILITES

# prints out the corpus id, total number of tokens, and total number of 
# unique tokens
setMethod("show", "StemmedCorpusView",
  function(object) {
    nUnique <- length(unique(object))
    nTotal <- sum(documentTokenMatrix(object)@Data)

    str <- paste("A stemmed corpus view with", nTotal, 
                 "total tokens and", nUnique, "unique tokens\n")
    cat(str)
  }
)
