# A view of an RSNLDocument that has been tokenized and stemmed in some way.
# Provides the user with easy access to a token vector, frequency
# table, and unique tokens.

### CLASS DEF

# Simply a TokenizedDocumentView with a stemmer slot (from
# StemmedView)
setClass("StemmedDocumentView",
    representation("StemmedView", "TokenizedDocumentView"))

### VALIDITY

# XXX TODO

### GENERICS

setGeneric("StemmedDocumentView",
  function (corpus, index, stemmer, tokenizer)
    standardGeneric("StemmedDocumentView"))

### CONSTRUCTION

# Constructs a new StemmedDocumentView
# Not part of the public interface, but should always be used within
# the library to create SDVs
setMethod("StemmedDocumentView", signature("PCorpus", "numeric"),
  function(corpus, index, stemmer, tokenizer) {
    tokens <- new("NULLcharacter")
    tokenFreqTable <- new("NULLtable")
    uniqueTokens <- new("NULLcharacter")

    res <- new("StemmedDocumentView", 
        corpus=corpus, index=index, tokenizer=tokenizer, tokens=tokens,
        tokenFreqTable=tokenFreqTable, uniqueTokens=uniqueTokens,
        stemmer=stemmer)

    registerView(corpus, res)
    return(res)
  }
)

### ACCESSORS/MODIFIERS (lazy loading)

# Returns the tokens of this view, stemmed
# XXX assumes a character-extending document type
setMethod("tokens", "StemmedDocumentView",
  function (object)
    if (is(ref(object, "tokens"), "NULLcharacter"))
      (ref(object, "tokens") <-
        stem(document(object), stemmer(object), tokenizer(object)))
    else
      ref(object, "tokens"))

### UTILS

# Prints some information about this view to the screen
setMethod("show", "StemmedDocumentView",
  function(object) {
    name <- ID(document(object))
    nTokens <- length(tokens(object))
    nUniqueTokens <- length(unique(object))

    str <- paste("A stemmed document view of", name, "with", nTokens, 
                 "total tokens and", nUniqueTokens, "unique tokens\n")
    cat(str)
  }
)
