# a base class for stemmers

### CLASS DEF

### Defined, as below, in StemmedView.R for technical reasons.
#setClass("Stemmer", representation("VIRTUAL"))

### GENERICS

setGeneric("stem",
  function(object, stemmer, tokenizer, index) standardGeneric("stem"))

### METHODS

# Particular stemmers
# override stem for character objects (and themselves); these
# overridden methods appear in the same file as the given stemmer
# class definition.

# The default stem behavior for characters is to assume that the
# character object contains a sequence of tokens when no tokenizer is
# given, but to tokenize the object first, if a tokenizer is
# specifically provided.  Note that we explicitly override the method
# for PlainTextDocument objects to provide tokenization in all cases.

# The method signature that all extenders must implement
setMethod("stem", signature(object="character", stemmer="Stemmer",
                            tokenizer="missing", index="missing"),
  function (object, stemmer, tokenizer, index)
    stop("stem must be implemented by derived class."))

# Calls the above method when a tokenizer is provided, after
# tokenizing
setMethod("stem", signature(object="character", stemmer="Stemmer",
                            tokenizer="Tokenizer", index="missing"),
  function (object, stemmer, tokenizer, index)
    stem(tokenize(object, tokenizer), stemmer))

# We've covered characater objects, but one can also stem
# PCorpus, TokenizedDocument, and TokenizedCorpus objects.  In the
# latter two cases the view provides tokenizer information and it
# makes no sense to pass a tokenizer along.

# Generate a StemmedCorpusView from a TokenizedCorpusView
setMethod("stem", signature(object="TokenizedCorpusView",
                            stemmer="Stemmer",
                            tokenizer="missing",
                            index="missing"),
  function (object, stemmer, tokenizer, index)
    StemmedCorpusView(corpus(object), stemmer, RSNL:::tokenizer(object)))

# Generate a StemmedDocumentView from a TokenizedCorpusView + index
setMethod("stem", signature(object="TokenizedCorpusView",
                            stemmer="Stemmer",
                            tokenizer="missing",
                            index="numeric"),
  function (object, stemmer, tokenizer, index)
    StemmedDocumentView(corpus(object), index, stemmer,
                        RSNL:::tokenizer(object)))

# Generate a StemmedCorpus from a PCorpus.
setMethod("stem", signature(object="PCorpus", 
                            stemmer="Stemmer",
                            index="missing"),
  function(object, stemmer, tokenizer, index) 
    if (missing(tokenizer))
      stem(tokenize(object), stemmer)
    else
      StemmedCorpusView(object, stemmer, tokenizer))

# Generate a StemmedDocumentView from a PCorpus + index.
setMethod("stem", signature(object="PCorpus",
                            stemmer="Stemmer",
                            index="numeric"),
  function (object, stemmer, tokenizer, index)
    if (missing(tokenizer))
      stem(tokenize(object), stemmer, index=index)
    else
      StemmedDocumentView(object, index, stemmer, tokenizer))

# Generate a StemmedDocumentView from a TokenizedDocumentView.
setMethod("stem", signature(object="TokenizedDocumentView",
                            stemmer="Stemmer",
                            tokenizer="missing",
                            index="missing"),
  function (object, stemmer, tokenizer, index)
    StemmedDocumentView(corpus(object), RSNL:::index(object), stemmer,
                        RSNL:::tokenizer(object)))


