# A view of a CorpusRef that has been tokenized and filtermed in some way.

### CLASS DEF

setClass("TokenFilteredCorpusView",
    representation("TokenizedCorpusView", "TokenFilteredView"))

### VALIDITY

# XXX TODO

### Various functions

### GENERICS

setGeneric("TokenFilteredCorpusView",
  function (corpus, filter, tokenizer)
    standardGeneric("TokenFilteredCorpusView"))

### CONSTRUCTION

# Constructs a new TokenFiltereddCorpusView from given corpus and tokenizer.
# This constructor is not intended to be part of the external api and
# users will generate TokenizedCorpusViews with the tokenize method.
# Always use this function to generate TFCVs within the library.
setMethod("TokenFilteredCorpusView", "PCorpus",
  function(corpus, filter, tokenizer) {
    documentViews <- new("NULLlist")
    tokenFreqTable <- new("NULLtable")
    uniqueTokens <- new("NULLcharacter")
    documentTokenMatrix <- new("NULLTermDocMatrix")

    res<- new("TokenFilteredCorpusView", corpus=corpus, tokenizer=tokenizer,
              documentViews=documentViews,
              tokenFreqTable=tokenFreqTable,
              uniqueTokens = uniqueTokens,
              documentTokenMatrix=documentTokenMatrix,
              filter=filter)
    registerView(corpus, res)
    res
  }
)

### ACCESSORS / MODIFIERS (lazy loading)

# Returns the documentViews of the underlying documents
setMethod("documentViews", "TokenFilteredCorpusView", 
  function (object) {
    if (is(ref(object, "documentViews"), "NULLlist")) {
      ftdvs <- lapply(1:length(corpus(object)),
        function (x) filterTokens(corpus(object), tokenFilter(object),
                                  tokenizer(object), x))
      names(ftdvs) <- sapply(corpus(object), ID)
      (ref(object, "documentViews") <- ftdvs)
    } else
      ref(object, "documentViews")
  }
)

# UTILITES

# prints out the corpus id, total number of tokens, and total number of 
# unique tokens
setMethod("show", "TokenFilteredCorpusView",
  function(object) {
    nUnique <- length(unique(object))
    nTotal <- sum(documentTokenMatrix(object)@Data)

    str <- paste("A token-filtered corpus view with", nTotal, 
                 "total tokens and", nUnique, "unique tokens\n")
    cat(str)
  }
)
