# A view of an RSNLDocument that has been tokenized and filtermed in some way.
# Provides the user with easy access to a token vector, frequency
# table, and unique tokens.

### CLASS DEF

# Simply a TokenizedDocumentView with a filter slot (from
# TokenFilteredView)
setClass("TokenFilteredDocumentView",
    representation("TokenFilteredView", "TokenizedDocumentView"))

### VALIDITY

# XXX TODO

### GENERICS

setGeneric("TokenFilteredDocumentView",
  function (corpus, index, filter, tokenizer)
    standardGeneric("TokenFilteredDocumentView"))

### CONSTRUCTION

# Constructs a new TokenFilteredDocumentView
# Not part of the public interface, but should always be used within
# the library to create TFDVs
setMethod("TokenFilteredDocumentView", signature("PCorpus", "numeric"),
  function(corpus, index, filter, tokenizer) {
    tokens <- new("NULLcharacter")
    tokenFreqTable <- new("NULLtable")
    uniqueTokens <- new("NULLcharacter")

    res <- new("TokenFilteredDocumentView", 
        corpus=corpus, index=index, tokenizer=tokenizer, tokens=tokens,
        tokenFreqTable=tokenFreqTable, uniqueTokens=uniqueTokens,
        filter=filter)

    registerView(corpus, res)
    return(res)
  }
)

### ACCESSORS/MODIFIERS (lazy loading)

# Returns the tokens of this view, filtermed
# XXX assumes a character-extending document type
setMethod("tokens", "TokenFilteredDocumentView",
  function (object)
    if (is(ref(object, "tokens"), "NULLcharacter"))
      (ref(object, "tokens") <-
        filterTokens(document(object), tokenFilter(object),
                     tokenizer(object)))
    else
      ref(object, "tokens"))

### UTILS

# Prints some information about this view to the screen
setMethod("show", "TokenFilteredDocumentView",
  function(object) {
    name <- ID(document(object))
    nTokens <- length(tokens(object))
    nUniqueTokens <- length(unique(object))

    str <- paste("A token-filtered document view of", name, "with",
        nTokens, "total tokens and", nUniqueTokens, "unique tokens\n")
    cat(str)
  }
)
