# A base class for all tokenized views.  Provides a slot for the
# tokenizer used and defines the tokenizer accessor method.

### BIZARRE PLACEMENT / FORWARD REFERENCE

# This is like a C++ forward reference...kinda.  Basically, because
# TokenizedView needs to know about Tokenizer, but the various
# basic tokenize method overridings need to know about
# TokenizedView's children, we define Tokenizer here, but define the
# methods in Tokenizer.R.  R loads TokenizedView.R, then
# TokenizedDocumentView, etc, and then Tokenizer.R and everything
# knows about everything it should.
setClass("Tokenizer", representation("VIRTUAL"))

### CLASS DEF

setClass("TokenizedView", 
  representation(tokenizer = "Tokenizer", "VIRTUAL"))

### GENERICS

setGeneric("tokenizer", function (object) standardGeneric("tokenizer"))

# All tokenized views should implement these methods

setGeneric("unique")

setGeneric("freqTable", function (object, ...) standardGeneric("freqTable"))

setGeneric("freq", 
  function (object, value, ...) standardGeneric("freq"))

setGeneric("has", function(object, value, ...) standardGeneric("has"))

### ACCESSORS

setMethod("tokenizer", "TokenizedView",
  function (object) return (object@tokenizer))
