\name{CorpusView-class}
\docType{class}
\alias{CorpusView-class}
\alias{[,CorpusView,ANY,missing,missing-method}
\alias{[[,CorpusView,ANY,missing-method}
\alias{corpus,CorpusView-method}
\alias{documentViews,CorpusView-method}
\alias{length,CorpusView-method}

\title{Class "CorpusView"}

\description{
  An abstract class representing a view of a \code{\linkS4class{PCorpus}}.
  \code{CorpusView} classes are used to view the content of a
  \code{\linkS4class{PCorpus}} in a new way.  \code{CorpusView}
  objects maintain soft references to the corpora that they view and
  automatically update themselves to reflect changes in a viewed
  corpus.
}

\section{Methods}{
  \describe{
    \item{[}{\code{signature(x = "CorpusView", i = "ANY", j =
    "missing", drop = "missing")}: Returns a slice of
    \code{\linkS4class{DocumentView}} objects.}

    \item{[[}{\code{signature(x = "CorpusView", i = "ANY", j = "missing")}:
    Returns a \code{\linkS4class{DocumentView}} object.}

    \item{documentViews}{\code{signature(object = "CorpusView")}:
    Returns a list containing all of the
    \code{\linkS4class{DocumentView}} objects held within the
    \code{CorpusView}. }

    \item{length}{\code{signature(x = "CorpusView")}: Returns the
    number of documents viewed by the \code{CorpusView}. }
	 }
}


\author{Tony Fader, Gary King, Dan Pemstein, and Kevin Quinn}

\seealso{
  \code{\linkS4class{TextDocument}}
  \code{\linkS4class{PCorpus}}
  \code{\linkS4class{DocumentView}}
}

\examples{
  # Demonstrate auto-updating
  data(crude)
  pcrude <- PCorpus(crude)
  tcrude <- tokenize(pcrude)
  toks1 <- unique(tcrude)
  tmMap(pcrude, tmTolower)
  isdiff <- length(toks1) == length(unique(tcrude))
}

\keyword{classes}
