\name{FunctionalTokenFilter-class}
\docType{class}
\alias{FunctionalTokenFilter-class}
\alias{filterTokens,character,FunctionalTokenFilter,missing,missing-method}
\alias{func,FunctionalTokenFilter-method}
\alias{isNegated,FunctionalTokenFilter-method}
\alias{mergeFilters,FunctionalTokenFilter,FunctionalTokenFilter-method}

\title{Class "FunctionalTokenFilter"}

\description{
  A \code{\linkS4class{TokenFilter}} that allows the user to employ an
  arbitrary function as a token filter.
}

\section{Objects from the Class}{
  Objects can be created by calls of the form
  \code{FunctionalTokenFilter(fun, negate)}.
}

\section{Extends}{
Class \code{"\linkS4class{TokenFilter}"}, directly.
}

\section{Methods}{
  \describe{
    \item{filterTokens}{\code{signature(object = "character",
                              filter = "FunctionalTokenFilter",
                              tokenizer = "missing",
                              index = "missing")}:
      Applies the filter to a \code{character} vector of tokens and
      returns a \code{character} vector of filtered tokens.  Note that
      this method will apply the default tokenizer to generate a token
      vector if \code{object} happens to be a
      \code{\linkS4class{TextDocument}}.}

    \item{func}{\code{signature(object = "FunctionalTokenFilter")}:
      Returns the function used by the filter to indicate tokens to
      keep. }

    \item{isNegated}{\code{signature(object = "FunctionalTokenFilter")}:
      When this is \code{TRUE} the filter keeps those tokens the
      filtering functions indicates it should not keep.}

    \item{mergeFilters}{\code{signature(f1 = "FunctionalTokenFilter",
                                        f2 = "FunctionalTokenFilter")}:
      Returns a new \code{FunctionalTokenFilter} that is the
      conjunction of the two arguments.}
	 }
}

\details{
  A \code{FunctionalTokenFilter} object encapsulates a simple function
  and uses it to filter a sequence of tokens.  The function should take
  a single \code{character} vector (one token per element) as its argument
  and return a \code{logical} vector of the same length as its input,
  indicating which tokens to keep.  If \code{negate} is set to true,
  this returned vector will, instead, indicate which tokens to filter
  out.
}

\author{Tony Fader, Gary King, Dan Pemstein, and Kevin Quinn}

\seealso{
  \code{\link{FunctionalTokenFilter}}
  \code{\link{filterTokens}}
  \code{\linkS4class{TokenFilter}}
  \code{\linkS4class{TokenFilteredView}}
  \code{\linkS4class{TokenFilteredDocumentView}}
  \code{\linkS4class{TokenFilteredCorpusView}}
}


\keyword{classes}
