\name{TaggedCorpusView-class}
\docType{class}
\alias{TaggedCorpusView-class}
\alias{documentTaggedTokenMatrix,TaggedCorpusView,missing-method}
\alias{documentTaggedTokenMatrix,TaggedCorpusView,WeightFunction-method}
\alias{documentTagMatrix,TaggedCorpusView,missing-method}
\alias{documentTagMatrix,TaggedCorpusView,WeightFunction-method}
\alias{freq,TaggedCorpusView,character-method}
\alias{freqTable,TaggedCorpusView-method}
\alias{has,TaggedCorpusView,character-method}
\alias{hasTag,TaggedCorpusView,character-method}
\alias{tagFreq,TaggedCorpusView,character-method}
\alias{tagFreqTable,TaggedCorpusView-method}
\alias{unique,TaggedCorpusView-method}
\alias{uniqueTags,TaggedCorpusView-method}

\title{Class "TaggedCorpusView"}

\description{
  A view of a \code{\linkS4class{PCorpus}} as a collection of
  \code{\linkS4class{TaggedDocumentView}} objects.
}

\section{Objects from the Class}{
    In general, \code{TaggedCorpusView} objects should not be
    constructed directly unless you are writing code to extend this
    package. Instead, they can be obtained from an existing 
    \code{\linkS4class{PCorpus}} object by calling
    \code{tag(corpus)}.

    If you are extending the package, the constructor function
    \code{TaggedCorpusView(tokenizedCorpusView, tagger)} can be used.
}

\section{Extends}{
Class \code{"\linkS4class{TaggedView}"}, directly.
Class \code{"\linkS4class{CorpusView}"}, directly.
}

\section{Methods}{
  \describe{
    \item{documentTaggedTokenMatrix}{\code{signature(object = 
                            "TaggedCorpusView", weight = "missing")}:
      Returns a \code{\linkS4class{TermDocMatrix}} object from the
      \code{TaggedCorpusView} where the terms are token-tag pairs of
      of the form "token/tag". }

    \item{documentTaggedTokenMatrix}{\code{signature(object = 
                        "TaggedCorpusView", weight = "WeightFunction")}:
      Returns a \code{\linkS4class{TermDocMatrix}} object from the
      \code{TaggedCorpusView} where the terms are token-tag pairs of
      of the form "token/tag", weighted by the given
      \code{\linkS4class{WeightFunction}} object. }

    \item{documentTagMatrix}{\code{signature(object = "TaggedCorpusView",
                                             weight = "missing")}:
      Returns a \code{\linkS4class{TermDocMatrix}} object of
      document-level tag frequencies from the \code{TaggedCorpusView}.  }

    \item{documentTagMatrix}{\code{signature(object = "TaggedCorpusView",
                                             weight = "WeightFunction")}:
      Returns a \code{\linkS4class{TermDocMatrix}} object of
      document-level tag frequencies from the \code{TaggedCorpusView},
      weighted by the given \code{\linkS4class{WeightFunction}}
      object. }

    \item{freq}{\code{signature(object = "TaggedCorpusView",
                                value = "character")}:
      Returns the frequency of the token-tag pair \code{value} within
      the \code{TaggedCorpusView}, where \code{value} is of the form
      "token/tag". }

    \item{freqTable}{\code{signature(object = "TaggedCorpusView")}:
      Returns a table of the frequencies of token-tag pairs within the
      \code{TaggedCorpusView}. }

    \item{has}{\code{signature(object = "TaggedCorpusView",
                               value = "character")}:
      Returns \code{TRUE} if the token-tag pair \code{value} is
      contained within the \code{TaggedCorpusView}. }

    \item{hasTag}{\code{signature(object = "TaggedCorpusView",
                                  value = "character")}:
      Returns \code{TRUE} if the tag \code{value} is contained within
      the \code{TaggedCorpusView}. }

    \item{tagFreq}{\code{signature(object = "TaggedCorpusView",
                                   value = "character")}:
      Returns the frequency of the tag \code{value} within
      the \code{TaggedCorpusView}. }

    \item{tagFreqTable}{\code{signature(object = "TaggedCorpusView")}:
      Returns a table of the frequencies of tags within the
      \code{TaggedCorpusView}. }

    \item{unique}{\code{signature(x = "TaggedCorpusView")}:
      Returns a character vector of the \code{TaggedCorpusView}'s
      unique token-tag pairs. }

    \item{uniqueTags}{\code{signature(object = "TaggedCorpusView")}:
      Returns a character vector of the \code{TaggedCorpusView}'s
      unique tags. }
	 }
}

\author{Tony Fader, Gary King, Dan Pemstein, and Kevin Quinn}

\seealso{
  \code{\link{tag}}
  \code{\linkS4class{CorpusView}}
  \code{\linkS4class{TaggedView}}
  \code{\linkS4class{TaggedDocumentView}}
  \code{\linkS4class{PCorpus}}
}

\keyword{classes}
