\name{TaggedDocumentView-class}
\docType{class}
\alias{TaggedDocumentView-class}
\alias{[,TaggedDocumentView,ANY,ANY,ANY-method}
\alias{freq,TaggedDocumentView,character-method}
\alias{freqTable,TaggedDocumentView-method}
\alias{has,TaggedDocumentView,character-method}
\alias{hasTag,TaggedDocumentView,character-method}
\alias{tagFreq,TaggedDocumentView,character-method}
\alias{tagFreqTable,TaggedDocumentView-method}
\alias{taggedTokens,TaggedDocumentView-method}
\alias{tags,TaggedDocumentView-method}
\alias{unique,TaggedDocumentView-method}
\alias{uniqueTags,TaggedDocumentView-method}

\title{Class "TaggedDocumentView"}

\description{
  A view of a \code{\linkS4class{TextDocument}} object (contained
  within a \code{\linkS4class{PCorpus}}) as a sequence of token
  labels, or tags.
}

\section{Objects from the Class}{
    In general, \code{TaggedDocumentView} objects should not be
    constructed directly unless you are writing code to extend this
    package. Instead, they can be obtained from an existing 
    \code{\linkS4class{PCorpus}} object by calling
    \code{tag(corpus, index=i)}.

    If you are extending the package, the constructor function
    \code{TaggedDocumentView(tokenizedDocumentView, tagger)}
    can be used.
}

\section{Extends}{
Class \code{"\linkS4class{TaggedView}"}, directly.
Class \code{"\linkS4class{DocumentView}"}, directly.
}

\section{Methods}{
  \describe{
    \item{[}{\code{signature(x = "TaggedDocumentView", i = "ANY", j = "ANY",
                             drop = "ANY")}:
      Returns specific tags, or slices of tags, at the given index
      \code{i}.}

    \item{freq}{\code{signature(object = "TaggedDocumentView",
                                value = "character")}:
      Returns the frequency of the token-tag pair \code{value} within the
      \code{TaggedDocumentView}.  The pair should be written in the
      form "token/tag". }

    \item{freqTable}{\code{signature(object = "TaggedDocumentView")}:
      Returns a table of the frequenices of token-tag pairs within the
      \code{TaggedDocumentView}. }

    \item{has}{\code{signature(object = "TaggedDocumentView",
                               value = "character")}:
      Returns \code{TRUE} if the token-tag pair \code{value} is
      contained within the \code{TaggedDocumentView}. }

    \item{hasTag}{\code{signature(object = "TaggedDocumentView",
                                  value = "character")}:
      Returns \code{TRUE} if the tag \code{value} is contained within
      the \code{TaggedDocumentView}. }

    \item{tagFreq}{\code{signature(object = "TaggedDocumentView",
                                   value = "character")}:
      Returns the frequency of the tag \code{value} within the
      \code{TaggedDocumentView}. }

    \item{tagFreqTable}{\code{signature(object = "TaggedDocumentView")}:
      Returns a table of the frequenices of tags within the
      \code{TaggedDocumentView}. }
      
    \item{taggedTokens}{\code{signature(object = "TaggedDocumentView")}:
      Returns a character vector of the \code{TaggedDocumentView}'s
      token-tag pairs, in the form \code{c("token1/tag1",
      "token2/tag2", ...)}. }

    \item{tags}{\code{signature(object = "TaggedDocumentView")}:
      Returns a character vector of the \code{TaggedDocumentView}'s
      tags. }

    \item{unique}{\code{signature(x = "TaggedDocumentView")}:
      Returns a character vector of the \code{TaggedDocumentView}'s
      unique token-tag pairs. }

    \item{uniqueTags}{\code{signature(object = "TaggedDocumentView")}:
      Returns a character vector of the \code{TaggedDocumentView}'s
      unique tags. }
	 }
}

\author{Tony Fader, Gary King, Dan Pemstein, and Kevin Quinn}

\seealso{
  \code{\link{tag}}
  \code{\linkS4class{DocumentView}}
  \code{\linkS4class{TaggedView}}
  \code{\linkS4class{TaggedCorpusView}}
  \code{\linkS4class{PCorpus}}
}

\keyword{classes}
