\name{TokenFilter-class}
\docType{class}
\alias{TokenFilter-class}
\alias{filterTokens,character,TokenFilter,missing,missing-method}
\alias{filterTokens,character,TokenFilter,Tokenizer,missing-method}
\alias{filterTokens,TokenizedCorpusView,TokenFilter,missing,missing-method}
\alias{filterTokens,TokenizedCorpusView,TokenFilter,missing,numeric-method}
\alias{filterTokens,TokenFilteredCorpusView,TokenFilter,missing,missing-method}
\alias{filterTokens,TokenFilteredCorpusView,TokenFilter,missing,numeric-method}
\alias{filterTokens,PCorpus,TokenFilter,ANY,missing-method}
\alias{filterTokens,PCorpus,TokenFilter,ANY,numeric-method}
\alias{filterTokens,TokenizedDocumentView,TokenFilter,missing,missing-method}
\alias{filterTokens,TokenFilteredDocumentView,TokenFilter,missing,missing-method}

\title{Class "TokenFilter"}

\description{
  An abstract class representing an object that takes a sequence of
  tokens and returns a subsequence of the original.
}

\section{Objects from the Class}{A virtual Class: No objects may be created from it.}

\section{Methods}{
  \describe{
    \item{filterTokens}{\code{signature(object = "character",
                                        filter = "TokenFilter",
                                        tokenizer = "missing",
                                        index = "missing")}:
      Apply the given filter to the \code{character} object and return
      a \code{character} vector of filtered tokens.}

    \item{filterTokens}{\code{signature(object = "character",
                                        filter = "TokenFilter",
                                        tokenizer = "Tokenizer",
                                        index = "missing")}:
      Apply the given filter to the \code{character} object, after
      first tokenizing with the given tokenizer, and return a
      \code{character} vector of filtered tokens.}

    \item{filterTokens}{\code{signature(object = "TokenizedCorpusView",
                                        filter = "TokenFilter",
                                        tokenizer = "missing",
                                        index = "missing")}:
      Apply the given filter to the
      \code{\linkS4class{TokenizedCorpusView}} and return a 
      \code{\linkS4class{TokenFilteredCorpusView}}. }

    \item{filterTokens}{\code{signature(object = "TokenizedCorpusView",
                                        filter = "TokenFilter",
                                        tokenizer = "missing",
                                        index = "numeric")}:
      Apply the given stemmer to the
      \code{\linkS4class{TokenizedDocumentView}} at \code{index}
      within the \code{\linkS4class{TokenizedCorpusView}} and return a
      \code{\linkS4class{TokenFilteredDocumentView}}. }
      
    \item{filterTokens}{\code{signature(object = "TokenFilteredCorpusView",
                                        filter = "TokenFilter",
                                        tokenizer = "missing",
                                        index = "missing")}:
      Apply the given filter to the
      \code{\linkS4class{TokenFilteredCorpusView}} and return a 
      \code{\linkS4class{TokenFilteredCorpusView}}.  The resulting
      view uses a filter that is the conjunction of the filter used by
      \code{object} and \code{filter}.}

    \item{filterTokens}{\code{signature(object = "TokenFilteredCorpusView",
                                        filter = "TokenFilter",
                                        tokenizer = "missing",
                                        index = "numeric")}:
      Apply the given stemmer to the
      \code{\linkS4class{TokenFilteredDocumentView}} at \code{index}
      within the \code{\linkS4class{TokenFilteredCorpusView}} and return a
      \code{\linkS4class{TokenFilteredDocumentView}}.  The resulting
      view uses a filter that is the conjunction of the filter used by
      \code{object} and \code{filter}.}
    
    \item{filterTokens}{\code{signature(object = "PCorpus",
                                        filter = "TokenFilter",
                                        tokenizer = "ANY",
                                        index = "missing")}:
      Apply the given filter to the \code{\linkS4class{PCorpus}} and
      return a \code{\linkS4class{TokenFilteredCorpusView}}. }

    \item{filterTokens}{\code{signature(object = "PCorpus",
                                        filter = "TokenFilter",
                                        tokenizer = "ANY",
                                        index = "numeric")}:
      Apply the given filter to the
      \code{\linkS4class{TextDocument}} at \code{index}
      within the \code{\linkS4class{PCorpus}} and return a
      \code{\linkS4class{TokenFilteredDocumentView}}. }

    \item{filterTokens}{\code{signature(object = "TokenizedDocumentView",
                                        filter = "TokenFilter",
                                        tokenizer = "missing",
                                        index = "missing")}:
      Apply the given stemmer to the
      \code{\linkS4class{TokenizedDocumentView}} and return a
      \code{\linkS4class{TokenFilteredDocumentView}}. }

    \item{filterTokens}{\code{signature(object = 
                                               "TokenFilteredDocumentView", 
                                        filter = "TokenFilter",
                                        tokenizer = "missing",
                                        index = "missing")}:
      Apply the given stemmer to the
      \code{\linkS4class{TokenizedDocumentView}} and return a
      \code{\linkS4class{TokenFilteredDocumentView}}.  The resulting
      view uses a filter that is the conjunction of the filter used by
      \code{object} and \code{filter}.}
	 }
}

\author{Tony Fader, Gary King, Dan Pemstein, and Kevin Quinn}

\seealso{
  \code{\link{filterTokens}}
  \code{\linkS4class{FunctionalTokenFilter}}
  \code{\linkS4class{RegexTokenFilter}}
  \code{\linkS4class{StopFilter}}
  \code{\linkS4class{TokenFilteredView}}
  \code{\linkS4class{TokenFilteredDocumentView}}
  \code{\linkS4class{TokenFilteredCorpusView}}
}



\keyword{classes}
