\name{TokenizedCorpusView-class}
\docType{class}
\alias{TokenizedCorpusView-class}
\alias{documentTokenMatrix,TokenizedCorpusView,missing-method}
\alias{documentTokenMatrix,TokenizedCorpusView,WeightFunction-method}
\alias{freq,TokenizedCorpusView,character-method}
\alias{freqTable,TokenizedCorpusView-method}
\alias{has,TokenizedCorpusView,character-method}
\alias{stem,TokenizedCorpusView,Stemmer,missing,missing-method}
\alias{stem,TokenizedCorpusView,Stemmer,missing,numeric-method}
\alias{tag,TokenizedCorpusView,Tagger,missing,missing-method}
\alias{tag,TokenizedCorpusView,Tagger,missing,numeric-method}
\alias{unique,TokenizedCorpusView-method}

\title{Class "TokenizedCorpusView"}

\description{A view of a \code{\linkS4class{PCorpus}} as a collection
of \code{\linkS4class{TokenizedDocumentView}} objects.}

\section{Objects from the Class}{
    In general, \code{TokenizedCorpusView} objects should not be
    constructed directly unless you are writing code to extend this
    package. Instead, they can be obtained from an existing 
    \code{\linkS4class{PCorpus}} object by calling
    \code{tokenize(corpus)}.

    If you are extending the package, the constructor function
    \code{TokenizedCorpusView(corpus, tokenizer)} can be used.
}

\section{Extends}{
Class \code{"\linkS4class{CorpusView}"}, directly.
Class \code{"\linkS4class{TokenizedView}"}, directly.
}

\section{Methods}{
  \describe{
    \item{documentTokenMatrix}{\code{signature(object = 
                                               "TokenizedCorpusView", 
                                               weight = "missing")}: 
      Returns a \code{\linkS4class{TermDocMatrix}} object, generated
      from the given \code{TokenizedCorpusView}.}

    \item{documentTokenMatrix}{\code{signature(object =
                                               "TokenizedCorpusView",
                                               weight = "WeightFunction")}:
      Returns a \code{\linkS4class{TermDocMatrix}} object, generated
      from the given \code{TokenizedCorpusView}, weighted by the given
      \code{\linkS4class{WeightFunction}} object.}

    \item{freq}{\code{signature(object = "TokenizedCorpusView",
                                value = "character")}:
      Returns the frequency of the token \code{value} within the
      \code{TokenizedCorpusView}.}

    \item{freqTable}{\code{signature(object = "TokenizedCorpusView")}:
      Returns a table of the frequencies of the tokens within the
      \code{TokenizedCorpusView}. }

    \item{has}{\code{signature(object = "TokenizedCorpusView",
                               value = "character")}:
      Returns \code{TRUE} if the token \code{value} is contained
      within the \code{TokenizedCorpusView}.}
    
    \item{stem}{\code{signature(object = "TokenizedCorpusView",
                                stemmer = "Stemmer", tokenizer = "missing",
                                index = "missing")}:
      Apply the given stemmer to the \code{TokenizedCorpusView} and
      return a \code{\linkS4class{StemmedCorpusView}}.}

    \item{stem}{\code{signature(object = "TokenizedCorpusView",
                                stemmer = "Stemmer", tokenizer = "missing",
                                index = "numeric")}:
      Apply the given stemmer to the \code{TokenizedDocumentView}
      contained in the \code{TokenizedCorpusView} at \code{index} and
      return a \code{\linkS4class{StemmedDocumentView}}. }

    \item{tag}{\code{signature(object = "TokenizedCorpusView",
                               tagger = "Tagger", tokenizer = "missing",
                               index = "missing")}:
      Apply the given tagger to the \code{TokenizedCorpusView} and
      return a \code{\linkS4class{TaggedCorpusView}}.}

    \item{tag}{\code{signature(object = "TokenizedCorpusView",
                               tagger = "Tagger", tokenizer = "missing",
                               index = "numeric")}:
      Apply the given tagger to the \code{TokenizedDocumentView}
      contained in the \code{TokenizedCorpusView} at \code{index} and
      return a \code{\linkS4class{TaggedDocumentView}}. }

    \item{unique}{\code{signature(x = "TokenizedCorpusView")}:
      Return a character vector of the \code{TokenizedCorpusView}'s
      unique tokens.}
  }
}

\author{Tony Fader, Gary King, Dan Pemstein, and Kevin Quinn}

\seealso{
  \code{\link{tokenize}}
  \code{\linkS4class{CorpusView}}
  \code{\linkS4class{TokenizedView}}
  \code{\linkS4class{TokenizedDocumentView}}
  \code{\linkS4class{PCorpus}}
}

\keyword{classes}
